@@ -33,6 +33,7 @@ import org.broad.igv.feature.LocusScore;
 import org.broad.igv.feature.Strand;
 import org.broad.igv.sam.mods.BaseModificationUtils;
 import org.broad.igv.sam.mods.BaseModificationSet;
+import org.broad.igv.sam.smrt.SMRTKinetics;
 import org.broad.igv.track.WindowFunction;
 
 import java.awt.*;
@@ -44,9 +45,17 @@ import java.util.Map;
  */
 public interface Alignment extends LocusScore {
 
-    String getReadName();
+    /**
+     * Name for the associated read.  Cannot be null.
+     * @return
+     */
+    default String getReadName() {
+        return "";
+    }
 
-    String getReadSequence();
+    default String getReadSequence() {
+        return "";
+    }
 
     String getChr();
 
@@ -66,6 +75,10 @@ public interface Alignment extends LocusScore {
 
     int getInferredInsertSize();
 
+    default int getLeadingHardClipLength() {
+        return 0;
+    }
+
     int getMappingQuality();
 
     ReadMate getMate();
@@ -123,9 +136,30 @@ public interface Alignment extends LocusScore {
     void finish();
 
     default AlignmentBlock getInsertionAt(int position) {
+        final AlignmentBlock[] insertions = getInsertions();
+        if(insertions == null) {
+            return null;
+        }
+        for (AlignmentBlock block : insertions) {
+            if (block.getStart() == position) return block;
+        }
         return null;
     }
 
+     default Gap getDeletionAt(int position) {
+         List<Gap> gaps = this.getGaps();
+         if (gaps != null && !gaps.isEmpty()) {
+             for (Gap gap : gaps) {
+                 if (gap.getStart() <= position
+                         && gap.getnBases() + gap.getStart() > position
+                         && gap.getType() == SAMAlignment.DELETION) {
+                     return gap;
+                 }
+             }
+         }
+         return null;
+     }
+
     default void setHaplotypeName(String hap) {}
 
     default String getHaplotypeName() {return null;}
@@ -138,7 +172,21 @@ public interface Alignment extends LocusScore {
 
     default List<BaseModificationSet> getBaseModificationSets() { return null;}
 
+    default SMRTKinetics getSmrtKinetics() { return null;}
+
+
     default String getAlignmentValueString(double position, int mouseX, AlignmentTrack.RenderOptions renderOptions) {
         return getValueString(position, mouseX, (WindowFunction) null);
     }
+
+    /**
+     * Get the most specific sub alignment which contains the given chromosome location, implementations which
+     * contain multiple distinct sub alignments should override this to provide the appropriate behavior
+     * Note: no check is performed to validate that the location is on the same chromosome as this alignment
+     * @param location the location on the chromosome to select an alignment from
+     * @return the alignment (or sub-alignment) that contains the given location, null if this alignment does not contain it
+     */
+    default Alignment getSpecificAlignment(double location) {
+        return this.contains(location) ? this : null;
+    }
 }
